/**
 * apeman task to babel cli commands.
 * @function apemanTaskBabel
 * @param {object} [options] - Optional settings.
 * @returns {function} - Defined task function.
 */

'use strict'

const argx = require('argx')
const execcli = require('execcli')
const co = require('co')

/** @lends define */
function define (src, options) {
  let args = argx(arguments)
  options = args.pop('object') || {}

  /**
   * Defined task.
   * @function task
   * @param {object} context - Apeman task context.
   * @returns {Promise}
   */
  function task (context) {
    let logger = context.logger
    return co(function * () {
      return yield define.babel([ src ].concat(options), {})
    })
  }

  Object.assign(task, {
    // Description of this task.
    $desc: 'Execute babel command.'
  })
  return task
}

define.babel = function (args, options) {
  let execOptions = Object.assign({
    notfound: 'try `npm install babel-cli -g`',
    search: [ process.cwd(), __dirname ]
  }, options)
  return new Promise((resolve, reject) =>
    execcli.npmBin('babel', args, execOptions, (err) =>
      err ? reject(err) : resolve()
    )
  )
}

module.exports = define

